import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//svg tag render
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//line graph creation
const render = data => { 
  //constants declaration
  const title = ' Auto Sales from 2004to 2012';
  
  const xValue = d => d.Year; //displaying years on x-axis
  const xAxisLabel = 'Year';

  const yValue = d => d.Sales; //displaying of sales on Y-axis
  const yAxisLabel = 'Sales';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  
  
  //centering g
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  // x-values creation
  const xScale = scaleTime()
  //set of values
    .domain(extent(data, xValue)) 
  //gives min and mix value in an array
    .range([0, innerWidth]) 
    .nice(); 
  //X Axis creation 
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  // Y values creation
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  //Y axis creation 
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  //Adding Y-axis label into svg
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Adding X axis label into svg
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //Creation of line graphs 
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); 
  
  //Addition of line graph to SVG
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
  //Additionof graph to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
//URL
csv('https://gist.githubusercontent.com/Pran6728/64f259cd9263276dde974f00bc238ef3/raw/7e82552918c966cae6191a878c7dc3e37a54b6fa/line.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.Sales = +d.Sales;
      d.Year = new Date(d.Year)
    });
    render(data);
  });